==> haskell-cryptonite-conduit-0.2.2-677-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-LQARCRlcP4g2DlHUCJOYqs
key:                  cryptonite-conduit-0.2.2-LQARCRlcP4g2DlHUCJOYqs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  96b63908eb659a8c39c160fff95ae93a
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-LQARCRlcP4g2DlHUCJOYqs
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva
    conduit-extra-1.3.6-2ISWqvhHdx25m1q6Z6zUj3
    cryptonite-0.30-AhJRgKpvPmBITEZW3Idbwt exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-679-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-I5W1H8vm2c430C1pGbiW5x
key:                  cryptonite-conduit-0.2.2-I5W1H8vm2c430C1pGbiW5x
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  a8e438af659e67c7a74fc4b244de0936
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-I5W1H8vm2c430C1pGbiW5x
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD
    conduit-extra-1.3.6-obyvRyqfW6FPvrQZmjt1V
    cryptonite-0.30-AhJRgKpvPmBITEZW3Idbwt exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
